@@ -175,7 +175,8 @@ class R3sponse(object):
 			else:
 				raise TypeError(e)
 		if comparison:
-			print(f"{Formats.Date().seconds_timestamp} - {color.fill(msg)}")
+			#print(f"{Formats.Date().seconds_timestamp} - {color.fill(msg)}")
+			print(f"{color.fill(msg)}")
 		if save: 
 			self.__log_to_file__(msg)
 		elif save_errors and _error_:
@@ -257,7 +258,7 @@ class ResponseObject(object):
 			#except: a=1
 		return self
 	# count items.
-	def len(self):
+	def __len__(self):
 		return len(self.keys())
 	# support item assignment.
 	def __setitem__(self, key, value):
